@@ -3,6 +3,7 @@ use std::time::Duration;
 #[allow(unused_imports)]
 use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 use tracing_futures::Instrument;
+use derivative::*;
 
 use crate::error::*;
 
@@ -48,7 +49,8 @@ use super::*;
 /// Chains also allow subscribe/publish models to be applied to
 /// particular vectors (see the examples for details)
 ///
-#[derive(Clone)]
+#[derive(Derivative, Clone)]
+#[derivative(Debug)]
 pub struct Chain {
     pub(crate) key: ChainKey,
     #[allow(dead_code)]
@@ -57,8 +59,10 @@ pub struct Chain {
     pub(crate) remote: Option<url::Url>,
     pub(crate) remote_addr: Option<MeshAddress>,
     pub(crate) default_format: MessageFormat,
+    #[derivative(Debug = "ignore")]
     pub(crate) inside_sync: Arc<StdRwLock<ChainProtectedSync>>,
     pub(crate) inside_async: Arc<RwLock<ChainProtectedAsync>>,
+    #[derivative(Debug = "ignore")]
     pub(crate) pipe: Arc<Box<dyn EventPipe>>,
     pub(crate) time: Arc<TimeKeeper>,
     pub(crate) exit: broadcast::Sender<()>,
