@@ -1,23 +1,18 @@
 use crate::crypto::AteHash;
 
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub enum CertificateValidation
-{
+pub enum CertificateValidation {
     DenyAll,
     AllowAll,
     AllowedCertificates(Vec<AteHash>),
 }
 
-impl CertificateValidation
-{
-    pub fn validate(&self, cert: &AteHash) -> bool
-    {
+impl CertificateValidation {
+    pub fn validate(&self, cert: &AteHash) -> bool {
         match self {
             CertificateValidation::DenyAll => false,
             CertificateValidation::AllowAll => true,
-            CertificateValidation::AllowedCertificates(a) => {
-                a.contains(cert)
-            }
+            CertificateValidation::AllowedCertificates(a) => a.contains(cert),
         }
     }
-}
\ No newline at end of file
+}
