@@ -7,6 +7,9 @@ use crate::meta::*;
 use async_trait::async_trait;
 use std::sync::Arc;
 use tokio::sync::mpsc;
+use bytes::Bytes;
+
+use crate::crypto::AteHash;
 
 pub enum ConnectionStatusChange {
     Disconnected,
@@ -33,6 +36,8 @@ pub(crate) trait EventPipe: Send + Sync {
         Ok(())
     }
 
+    async fn load_many(&self, leafs: Vec<AteHash>) -> Result<Vec<Option<Bytes>>, LoadError>;
+
     async fn feed(&self, work: ChainWork) -> Result<(), CommitError>;
 
     async fn try_lock(&self, key: PrimaryKey) -> Result<bool, CommitError>;
@@ -61,6 +66,13 @@ impl EventPipe for NullPipe {
         Ok(())
     }
 
+    async fn load_many(&self, leafs: Vec<AteHash>) -> Result<Vec<Option<Bytes>>, LoadError> {
+        Ok(leafs
+            .into_iter()
+            .map(|_| None)
+            .collect())
+    }
+
     async fn try_lock(&self, _key: PrimaryKey) -> Result<bool, CommitError> {
         Ok(false)
     }
@@ -167,6 +179,39 @@ impl EventPipe for DuelPipe {
         Ok(())
     }
 
+    async fn load_many(&self, leafs: Vec<AteHash>) -> Result<Vec<Option<Bytes>>, LoadError> {
+        let join1 = self.first.load_many(leafs.clone());
+        let join2 = self.second.load_many(leafs);
+        let (notify1, notify2) = futures::join!(join1, join2);
+
+        let rets = match (notify1, notify2) {
+            (Ok(notify1), Ok(notify2)) => {
+                let max = notify1.len().max(notify2.len());
+                
+                let mut notify1 = notify1.into_iter();
+                let mut notify2 = notify2.into_iter();
+
+                let mut rets = Vec::new();
+                for _ in 0..max {
+                    match (notify1.next(), notify2.next()) {
+                        (Some(Some(a)), _) => rets.push(Some(a)),
+                        (_, Some(Some(b))) => rets.push(Some(b)),
+                        (Some(None), _) => rets.push(None),
+                        (_, Some(None)) => rets.push(None),
+                        (_, _) => break,
+                    };
+                }                
+                rets
+            },
+            (Ok(notify1), Err(_)) => notify1,
+            (Err(_), Ok(notify2)) => notify2,
+            (Err(err), Err(_)) => {
+                return Err(err);
+            }
+        };
+        Ok(rets)
+    }
+
     async fn try_lock(&self, key: PrimaryKey) -> Result<bool, CommitError> {
         Ok(self.first.try_lock(key).await? || self.second.try_lock(key).await?)
     }
