@@ -27,7 +27,7 @@ where
 
     async fn write(
         &mut self,
-        evt: &EventData,
+        evt: &EventWeakData,
     ) -> std::result::Result<LogLookup, SerializationError>;
 
     async fn copy_event(
@@ -36,7 +36,7 @@ where
         hash: AteHash,
     ) -> std::result::Result<LogLookup, LoadError>;
 
-    async fn load(&self, hash: AteHash) -> std::result::Result<LoadData, LoadError>;
+    async fn load(&self, hash: &AteHash) -> std::result::Result<LoadData, LoadError>;
 
     fn move_log_file(&mut self, new_path: &String) -> Result<()>;
 
