@@ -77,6 +77,14 @@ pub trait AteSession: Send + Sync + std::fmt::Display {
     fn clone_inner(&self) -> AteSessionInner;
 }
 
+impl std::fmt::Debug
+for dyn AteSession
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        std::fmt::Display::fmt(self, f)
+    }
+}
+
 impl From<AteSessionUser> for Box<dyn AteSession> {
     fn from(session: AteSessionUser) -> Self {
         Box::new(session)
@@ -113,6 +121,7 @@ pub enum AteSessionKeyCategory {
     UserKeys,
     SudoKeys,
     GroupKeys,
+    BrokerKeys,
     NonGroupKeys,
     AllKeys,
 }
@@ -141,4 +150,11 @@ impl AteSessionKeyCategory {
             _ => false,
         }
     }
+    pub fn includes_broker_keys(&self) -> bool {
+        match self {
+            AteSessionKeyCategory::BrokerKeys => true,
+            AteSessionKeyCategory::AllKeys => true,
+            _ => false,
+        }
+    }
 }
